---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

- which operating system are you using?  
e.g. Windows 10, Ubuntu 18.4, etc.
- which environment is pyroSAR running in?  
e.g. system-wide Python installation, Anaconda environment, virtual environment, etc.
- which version of pyroSAR are you using?  
one installed via conda, pip or a clone of the GitHub repository?
-  which function of pyroSAR did you call with which parameters?  
- if applicable, which version of SNAP or GAMMA are you using in pyroSAR?
- the full error message
